@@ -436,12 +436,14 @@ mspcdsty1 <- function(s,r,id.basis,cnt,int.s,int.r,prec,maxiter,alpha,skip.iter)
     cd <- rep(0,nxi+nnull)
     scal <- NULL
     la <- log.la0
+    mn0 <- log.la0-6
+    mx0 <- log.la0+6
     repeat {
-        mn <- la-1
-        mx <- la+1
-        if (mx>log.la0+6) break
+        mn <- max(la-1,mn0)
+        mx <- min(la+1,mx0)
         zz <- nlm0(cv.s,c(mn,mx))
-        if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+        if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+            (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
         else la <- zz$est
     }
     if (nq==1) {
@@ -482,12 +484,14 @@ mspcdsty1 <- function(s,r,id.basis,cnt,int.s,int.r,prec,maxiter,alpha,skip.iter)
     ## fixed theta iteration
     cd <- rep(0,nxi+nnull)
     la <- log.la0
+    mn0 <- log.la0-6
+    mx0 <- log.la0+6
     repeat {
-        mn <- la-1
-        mx <- la+1
-        if (mx>log.la0+6) break
+        mn <- max(la-1,mn0)
+        mx <- min(la+1,mx0)
         zz <- nlm0(cv.s,c(mn,mx))
-        if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+        if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+            (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
         else la <- zz$est
     }
     lambda <- zz$est
